#!/usr/bin/gawk -f

# DEBUGGING VERSION (w. x, y)

BEGIN{
  pi = 4.*atan2(1.,1.); deg=pi/180.;
  major = 1.e-3;
  minor = 1.e-3;
  PA_ellipse = 0.0*deg;

  ID = ARGV[1];
  ARGV[1] = "";

  n=0;
  last=0.0;
  a = 0.0;
  b = 0.0;
  R = 0.0;

  OFMT="%.6f";
  print "# JD (i.e. uncorrected for LITE) & one [] & two [] & x [arcsec] & y [arcsec] & vx [arcsec/day] & vy [arcsec/day] & major [arcsec/day] & minor [arcsec/day] & PA [deg] of uncertainty ellipse & d [au] & l [deg] & b [deg] (all from Horizons; i.e. corrected for LITE) & Besselian year & dataset";
#  print "# JD (i.e. uncorrected for LITE) & one [] & two [] & vx [arcsec/day] & vy [arcsec/day] & major [arcsec/day] & minor [arcsec/day] & PA [deg] of uncertainty ellipse & d [au] & l [deg] & b [deg] (all from Horizons; i.e. corrected for LITE) & Besselian year & dataset";
}
!/^#/ && (NF>0){
  if ($1-last > 0.01) {
    prn();
    n=0;
  }
  n++;
  t[n] = $1;
  sep = $2;
  ang = $3*deg;
  x[n] = -sep*sin(ang);
  y[n] = sep*cos(ang);
  d[n] = $7;
  l[n] = $8;
  b_[n] = $9;
  bessel[n] = $10;
  dataset[n] = $11;
  last = $1;
}
END{
  prn();
}

func prn() {
  if (n>1) {
#    t0 = mean(t,n);
    t0 = t[1];
    for (i=1; i<=n; i++) {
#      print t[i];  # dbg
      t[i] = t[i]-t0;
    }
    lsm(t,x,n); vx = a;
    lsm(t,y,n); vy = a;
    print t0 "	" 1 " 	" ID "	" x[1] "	" y[1] "	" sprintf("%.6e", vx) "	" sprintf("%.6e", vy) "	" major "	" minor "	" PA_ellipse/deg "	" d[1] "	" l[1] "	" b_[1] "	" bessel[1] "	" dataset[1] "	# n = " n;
#    print t0 "	" 1 " 	" ID "	" sprintf("%.6e", vx) "	" sprintf("%.6e", vy) "	" major "	" minor "	" PA_ellipse/deg "	" d[1] "	" l[1] "	" b_[1] "	" bessel[1] "	" dataset[1] "	# n = " n;
  } else {
  }
}

func mean(x,n, i,Sx) {
  Sx = 0.0;
  for (i=1; i<=n; i++) {
    Sx = Sx+x[i];
  }
  xm = Sx/n;
  return xm;
}

# LSM fit (y = a*x + b)

func lsm(x,y,n, i,Sx,Sxx,Sy,Syy,Sxy) {
  Sx  = 0.0;
  Sxx = 0.0;
  Sy  = 0.0;
  Syy = 0.0;
  Sxy = 0.0;
  
  for (i=1; i<=n; i++) {
    Sx  = Sx  + x[i];
    Sxx = Sxx + x[i]*x[i];
    Sy  = Sy  + y[i];
    Syy = Syy + y[i]*y[i];
    Sxy = Sxy + x[i]*y[i];
  }

  a = (n*Sxy-Sx*Sy)/(n*Sxx-Sx*Sx);
  b = (Sy-a*Sx)/n;

  R = (n*Sxy-Sx*Sy)/sqrt((n*Sxx-Sx*Sx)*(n*Syy-Sy*Sy));
#  a = Sy/Sx;  # for b = 0
  return;
}



